import { RgbaColor } from '../types';
/**
 * Additional options for K-Means color extractor
 */
export interface KMeansColorExtractorOptions {
    /**
     * Maximum number of loops the algorithm can perform (default 10).
     * This number can be increased to have more accurate colors,
     * but depending on the range of colors being it might take longer to finish.
     *
     * If the algorithm finishes its calculation before reaching the end,
     * it will immediately return the colors found.
     */
    maxRuns: number;
    /**
     * Whether consider the alpha channel while finding the colors (default false).
     */
    withAlpha: boolean;
    /**
     * Use random parts of the array as the initial values or offset based (default false).
     */
    randomSeed: boolean;
    /**
     * After extracting the colors,
     * should it return the nearest colors of each group or the median color of each group? (default true)
     *
     * With this option enabled it will return only colors that are part of color set.
     * This option is useful if colors from a logo are being extracted,
     * so only colors that are part of the logo will be returned.
     */
    nearestColors: boolean;
}
/**
 * Extracts colors using the K-Means algorithm.
 * With that approach the colors can be found by finding the mean color on each group.
 * Where the colors are grouped based on their RGB distance.
 *
 * @param colors the list of all colors to be considered
 * @param count the number of colors to be extracted
 * @param options additional options {@see KMeansColorExtractorOptions} for more details
 */
declare const kMeansColorExtractor: (colors: RgbaColor[], count: number, options?: Partial<KMeansColorExtractorOptions> | undefined) => RgbaColor[];
export default kMeansColorExtractor;
